@@ -6,7 +6,7 @@ module fpm_git
     implicit none
 
     public :: git_target_t, git_target_default, git_target_branch, git_target_tag, git_target_revision, git_revision, &
-            & git_archive, git_matches_manifest, operator(==), compressed_package_name
+            & git_archive, git_matches_manifest, compressed_package_name
 
     !> Name of the compressed package that is generated temporarily.
     character(len=*), parameter :: compressed_package_name = 'compressed_package'
@@ -62,11 +62,6 @@ module fpm_git
 
     end type git_target_t
 
-
-    interface operator(==)
-        module procedure git_target_eq
-    end interface
-
     !> Common output format for writing to the command line
     character(len=*), parameter :: out_fmt = '("#", *(1x, g0))'
 
@@ -144,18 +139,6 @@ contains
 
     end function git_target_tag
 
-    !> Check that two git targets are equal
-    logical function git_target_eq(this,that) result(is_equal)
-
-        !> Two input git targets
-        type(git_target_t), intent(in) :: this,that
-
-        is_equal = this%descriptor == that%descriptor .and. &
-                   this%url        == that%url        .and. &
-                   this%object     == that%object
-
-    end function git_target_eq
-
     !> Check that two git targets are equal
     logical function git_is_same(this,that)
         class(git_target_t), intent(in) :: this
@@ -424,20 +407,22 @@ contains
     end function descriptor_name
 
   !> Archive a folder using `git archive`.
-  subroutine git_archive(source, destination, ref, verbose, error)
+  subroutine git_archive(source, destination, ref, additional_files, verbose, error)
     !> Directory to archive.
     character(*), intent(in) :: source
     !> Destination of the archive.
     character(*), intent(in) :: destination
     !> (Symbolic) Reference to be archived.
     character(*), intent(in) :: ref
+    !> (Optional) list of additional untracked files to be added to the archive.
+    character(*), optional, intent(in) :: additional_files(:)
     !> Print additional information if true.
     logical, intent(in) :: verbose
     !> Error handling.
     type(error_t), allocatable, intent(out) :: error
 
-    integer :: stat
-    character(len=:), allocatable :: cmd_output, archive_format
+    integer :: stat,i
+    character(len=:), allocatable :: cmd_output, archive_format, add_files
 
     call execute_and_read_output('git archive -l', cmd_output, error, verbose)
     if (allocated(error)) return
@@ -448,7 +433,20 @@ contains
       call fatal_error(error, "Cannot find a suitable archive format for 'git archive'."); return
     end if
 
-    call run('git archive '//ref//' --format='//archive_format//' -o '//destination, echo=verbose, exitstat=stat)
+    allocate(character(len=0) :: add_files)
+    if (present(additional_files)) then 
+       do i=1,size(additional_files)
+          add_files = trim(add_files)//' --add-file='//adjustl(additional_files(i))
+       end do
+    endif
+
+    call run('git archive '//ref//' &
+        & --format='//archive_format// &
+        & add_files//' &
+        & -o '//destination, &
+        & echo=verbose, &
+        & exitstat=stat)
+        
     if (stat /= 0) then
       call fatal_error(error, "Error packing '"//source//"'."); return
     end if
