@@ -28,7 +28,8 @@ use fpm_environment,  only : get_os_type, get_env, &
                              OS_CYGWIN, OS_SOLARIS, OS_FREEBSD, OS_OPENBSD, OS_NAME
 use M_CLI2,           only : set_args, lget, sget, unnamed, remaining, specified
 use M_CLI2,           only : get_subcommand, CLI_RESPONSE_FILE
-use fpm_strings,      only : lower, split, to_fortran_name, is_fortran_name, remove_characters_in_set, string_t
+use fpm_strings,      only : lower, split, to_fortran_name, is_fortran_name, remove_characters_in_set, &
+                             string_t, glob
 use fpm_filesystem,   only : basename, canon_path, which, run
 use fpm_environment,  only : get_command_arguments_quoted
 use fpm_error,        only : fpm_stop, error_t
@@ -51,7 +52,8 @@ public :: fpm_cmd_settings, &
           fpm_update_settings, &
           fpm_clean_settings, &
           fpm_publish_settings, &
-          get_command_line_settings
+          get_command_line_settings, &
+          get_fpm_env
 
 type, abstract :: fpm_cmd_settings
     character(len=:), allocatable :: working_dir
@@ -96,6 +98,7 @@ type, extends(fpm_build_settings)  :: fpm_run_settings
     logical :: example
     contains
        procedure :: runner_command
+       procedure :: name_ID
 end type
 
 type, extends(fpm_run_settings)  :: fpm_test_settings
@@ -105,6 +108,7 @@ type, extends(fpm_build_settings) :: fpm_install_settings
     character(len=:), allocatable :: prefix
     character(len=:), allocatable :: bindir
     character(len=:), allocatable :: libdir
+    character(len=:), allocatable :: testdir
     character(len=:), allocatable :: includedir
     logical :: no_rebuild
 end type
@@ -530,8 +534,8 @@ contains
         case('install')
             call set_args(common_args // compiler_args // '&
                 & --no-rebuild F --prefix " " &
-                & --list F &
-                & --libdir "lib" --bindir "bin" --includedir "include"', &
+                & --list F --test F &
+                & --libdir "lib" --bindir "bin" --testdir "test" --includedir "include"', &
                 help_install, version_text)
 
             call check_build_vals()
@@ -541,6 +545,7 @@ contains
             archiver = sget('archiver')
             allocate(install_settings, source=fpm_install_settings(&
                 list=lget('list'), &
+                build_tests=lget('test'), &
                 profile=val_profile,&
                 prune=.not.lget('no-prune'), &
                 compiler=val_compiler, &
@@ -555,6 +560,7 @@ contains
                 verbose=lget('verbose')))
             call get_char_arg(install_settings%prefix, 'prefix')
             call get_char_arg(install_settings%libdir, 'libdir')
+            call get_char_arg(install_settings%testdir, 'testdir')
             call get_char_arg(install_settings%bindir, 'bindir')
             call get_char_arg(install_settings%includedir, 'includedir')
             call move_alloc(install_settings, cmd_settings)
@@ -1415,6 +1421,7 @@ contains
     help_text_build_common,&
     help_text_flag, &
     ' --no-rebuild      do not rebuild project before installation', &
+    ' --test            also install test programs', &
     ' --prefix DIR      path to installation directory (requires write access),', &
     '                   the default prefix on Unix systems is $HOME/.local', &
     '                   and %APPDATA%\local on Windows', &
@@ -1423,6 +1430,7 @@ contains
     '                   (default: lib)', &
     ' --includedir DIR  subdirectory to place headers and module files in', &
     '                   (default: include)', &
+    ' --testdir DIR     subdirectory to place test programs in (default: test)', & 
     ' --verbose         print more information', &
     '', &
     help_text_environment, &
@@ -1439,6 +1447,9 @@ contains
     ' 3. Install executables to a custom prefix into the exe directory:', &
     '', &
     '    fpm install --prefix $PWD --bindir exe', &
+    ' 4. Install executables and test programs into the same "exe" directory:', &
+    '', &
+    '    fpm install --prefix $PWD --test --bindir exe --testdir exe', &
     '' ]
     help_clean=[character(len=80) :: &
     'NAME', &
@@ -1541,5 +1552,27 @@ contains
         if (len_trim(cmd%runner_args)>0) run_cmd = run_cmd//' '//trim(cmd%runner_args)
     end function runner_command
 
+    !> Check name in list ID. return 0 if not found
+    integer function name_ID(cmd,name)
+       class(fpm_run_settings), intent(in) :: cmd
+       character(*), intent(in) :: name
+       
+       integer :: j
+       
+       !> Default: not found
+       name_ID = 0
+       if (.not.allocated(cmd%name)) return
+       
+       do j=1,size(cmd%name)
+          
+          if (glob(trim(name),trim(cmd%name(j)))) then 
+              name_ID = j
+              return
+          end if
+          
+       end do
+    
+    end function name_ID
+
 
 end module fpm_command_line
