@@ -132,6 +132,10 @@ type build_target_t
 
     !> Version number
     character(:), allocatable :: version
+    
+    contains
+    
+        procedure :: is_executable_target
 
 end type build_target_t
 
@@ -1043,7 +1047,7 @@ end subroutine filter_executable_targets
 
 
 elemental function is_executable_target(target_ptr, scope) result(is_exe)
-    type(build_target_t), intent(in) :: target_ptr
+    class(build_target_t), intent(in) :: target_ptr
     integer, intent(in) :: scope
     logical :: is_exe
     is_exe = target_ptr%target_type == FPM_TARGET_EXECUTABLE .and. &
@@ -1101,5 +1105,4 @@ function get_feature_flags(compiler, features) result(flags)
     end if
 end function get_feature_flags
 
-
 end module fpm_targets
